/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.LoginPage;
import org.alfresco.po.share.SharePage;

/**
 * Process an Alfresco share logout by mimicking real user selecting the logout button on the page.
 * 
 * <h1>Input</h1>
 * 
 * {@link ShareEventData} with a valid {@link ShareEventData#getSharePage() Share page}.
 *  
 * <h1>Actions</h1>
 * 
 * Clicks the {@link WebDriverUtil#logout logout} button
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_LOGOUT_COMPLETE}: Logged out {@link SharePage} using {@link ShareEventData}<br/>
 * 
 * @author Michael Suzuki
 * @since 1.0
 */
public class LogoutEventProcess extends AbstractShareEventProcessor
{
    private final static String EVENT_NAME_LOGOUT_COMPLETE = "share.logout.complete";
    
    /**
     * @param userData name of DB collection containing user details
     */
    public LogoutEventProcess(UserDataService userDataService)
    {
        super(userDataService, EVENT_NAME_LOGOUT_COMPLETE);
    }

    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        EventResult result = null;
        String username = eventData.getUsername();
        SharePage sharePage = eventData.getSharePage().getCurrentPage().render();
        LoginPage page = sharePage.getNav().logout().render();
        eventData.setSharePage(page);
        Event close = new Event(eventNameActionComplete, eventData);
        result = new EventResult(
                String.format("%s has logged out successfully", username),
                close);
        return result;
    }

}
