/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.PeopleFinderPage;

/**
 * Enters a String into into the search box on the {@link PeopleFinderPage} and submits.
 *  
 * <h1>Input</h1>
 *  
 * {@link ShareEventData} with a {@link PeopleFinderPage} containing the search box and
 * a {@link ShareEventData#getSearch() search term}. 
 * 
 * <h1>Actions</h1>
 * 
 * Performs the search for people
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_PEOPLE_SEARCH_COMPLETE}: {@link ShareEventData} with {@link PeopleFinderPage}<br/>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class PeopleSearchEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_PEOPLE_SEARCH_COMPLETE = "share.people.search.complete";

    public PeopleSearchEventProcess(UserDataService userDataService)
    {
        super(userDataService,EVENT_NAME_PEOPLE_SEARCH_COMPLETE);
    }
    
    /**
     * Process which enters the term into search box on {@link PeopleFinderPage} and
     * performs the search.
     * 
     * @param eventData {@link Event} event information
     * @return {@link EventResult} result of the process
     */
    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        String searchTerm = eventData.getSearch();
        if (null == searchTerm)
        {
            return new EventResult("No search term provided for People Finder.", false);
        }
        
        PeopleFinderPage peopleFinderPage = (PeopleFinderPage) eventData.getSharePage();
        PeopleFinderPage peopleFinderPageResults = peopleFinderPage.searchFor(searchTerm).render();
        eventData.setSharePage(peopleFinderPageResults);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Successfully searched people for: " + searchTerm,
                nextEvent);
        return result;
    }
}
