/*
 * Copyright (C) 2005-2017 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */

package org.alfresco.bm.process.share;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.DashBoardPage;
import org.alfresco.po.share.CustomiseUserDashboardPage;


/**
 * 
 * Navigate to Alfresco share user dashboard customise page, mimics the action of selecting the customise 
 * user dashboard page button from the user dashboard.
 *  
 * <h1>Input</h1> 
 * 
 * {@link ShareEventData} containing:<br/>
 * {@link UserDashboardPage}.
 * 
 * <h1>Actions</h1>
 * 
 * Selects the customize user dashboard navigation button
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_SELECT_CUSTOMISE_USER_DASHBOARD}: {@link UserDashboardPage} in {@link ShareEventData}<br/>
 * 
 * 
 * @author jcule
 *
 */
public class SelectCustomiseUserDashboardEventProcess extends AbstractShareEventProcessor
{
	public static final String EVENT_NAME_SELECT_CUSTOMISE_USER_DASHBOARD = "event.share.customiseUserDashboard.complete";

	public SelectCustomiseUserDashboardEventProcess(UserDataService userDataService) 
	{
		super(userDataService,EVENT_NAME_SELECT_CUSTOMISE_USER_DASHBOARD);
	}

	
	/**
     * Process which looks for the customize dashboard link on the user dashboard page and clicks it
     * to redirect user to the customize user dashboard page.
     * 
     * @param eventData {@link Event} event information
     * @return {@link EventResult} result of the process
     */
	@Override
	protected EventResult processEvent(Event event, ShareEventData eventData) throws Exception {
        ShareEventData pagingEventData = (ShareEventData) eventData;
        DashBoardPage dashBoardPage = (DashBoardPage) pagingEventData.getSharePage();
        CustomiseUserDashboardPage customiseUserDashboardPage = dashBoardPage.getNav().selectCustomizeUserDashboard().render();
        String pageTitle = customiseUserDashboardPage.getPageTitle();
        eventData.setSharePage(customiseUserDashboardPage);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Clicked customise on dashboard " + pageTitle ,
                nextEvent);
        return result;		
	}

}
