/*
 * Copyright (C) 2005-2012 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.entity;

/**
 * Extension of {@link ShareEventData} that holds extra paging information.
 * <ul>
 *     <li>direction</li>
 *     <li>page number</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class SharePagingEventData extends ShareEventData 
{
    private final boolean forward;
    private final int page;

    /**
     * Constructor.
     * 
     * @param copyFrom          existing data to copy values from
     * @param forward           <tt>true</tt> to indicate forward paging (default)
     * @param page              the page number
     */
    public SharePagingEventData(ShareEventData copyFrom, boolean forward, int page)
    {
        super(copyFrom);
        
        this.forward = forward;
        this.page = page;
    }

    public int getPageNumber()
    {
        return page;
    }

    public boolean isForward()
    {
        return forward;
    }    
}
