/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.entity;

/**
 * Extension of {@link ShareEventData} that holds data for doclib entry selection
 * <ul>
 *     <li>entry</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.1
 */
public class ShareSelectDocLibEntryEventData extends ShareEventData 
{
    private final String entry;
    private int depth;

    /**
     * Constructor.
     * 
     * @param copyFrom          existing data to copy values from
     * @param entry             the entry to select
     */
    public ShareSelectDocLibEntryEventData(ShareEventData copyFrom, String entry)
    {
        super(copyFrom);
        
        if (entry == null)
        {
            throw new IllegalArgumentException("'entry' may not be null.");
        }
        
        this.entry = entry;
        
        if (copyFrom instanceof ShareSelectDocLibEntryEventData)
        {
            ShareSelectDocLibEntryEventData copyFromExact = (ShareSelectDocLibEntryEventData) copyFrom;
            depth = copyFromExact.getDepth();
        }
        else
        {
            depth = 0;
        }
    }
    
    public String getEntry()
    {
        return entry;
    }

    /**
     * Get the number of times the doclib selection has passed through the same scenario
     * @return
     */
    public synchronized int getDepth()
    {
        return depth;
    }
    
    /**
     * Increment the depth count by one
     * 
     * @return          the new, increased depth
     */
    public synchronized int incrementDepth()
    {
        return ++depth;
    }
}
