/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.site;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.event.EventResult;
import org.alfresco.bm.process.share.AbstractShareEventProcessor;
import org.alfresco.bm.process.share.ShareEventProcessException;
import org.alfresco.bm.process.share.entity.ShareCreateFolderEventData;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.user.UserDataService;
import org.alfresco.po.share.site.NewFolderPage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Fill in new folder details and click Save.
 *  
 * <h1>Input</h1>
 *  
 * {@link ShareEventData} containing {@link NewFolderPage} and a
 * {@link ShareEventData#getFilename() folder name}.
 * 
 * <h1>Actions</h1>
 * 
 * Fills in details and clicks <i>Save</i>.
 * 
 * <h1>Output</h1>
 * 
 * {@link #EVENT_NAME_CREATE_FOLDER_COMPLETE}: {@link DocumentLibraryPage} in {@link ShareEventData}<br/>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class CreateFolderEventProcess extends AbstractShareEventProcessor
{
    public static final String EVENT_NAME_CREATE_FOLDER_COMPLETE = "share.doclib.createFolder.complete";

    public CreateFolderEventProcess(UserDataService userDataService)
    {
        super(userDataService,EVENT_NAME_CREATE_FOLDER_COMPLETE);
    }
    
    /**
     * Process which selects the <i>New Folder</i>.
     * 
     * @param eventData {@link Event} event information
     * @return {@link EventResult} result of the process
     */
    @Override
    public EventResult processEvent(Event event, ShareEventData eventData) throws Exception
    {
        if (!(eventData instanceof ShareCreateFolderEventData))
        {
            throw new ShareEventProcessException("Folder creation must be done with ShareCreateFolderEventData.");
        }
        ShareCreateFolderEventData createFolderEventData = (ShareCreateFolderEventData) eventData;
        String name = createFolderEventData.getFolderName();
        String description = "Created by session " + event.getSessionId();
        
        NewFolderPage newFolderPage = (NewFolderPage) eventData.getSharePage();
        DocumentLibraryPage doclibPage = newFolderPage.createNewFolder(name, description).render();
        eventData.setSharePage(doclibPage);
        Event nextEvent = new Event(eventNameActionComplete, eventData);
        EventResult result = new EventResult(
                "Create folder: " + name,
                nextEvent);
        return result;
    }
}
