/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.Collections;
import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.po.share.SharePage;
import org.alfresco.po.share.site.SiteDashboardPage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Browses to a site document library.
 * <p/>
 * This class uses the {@link ShareBrowseToSiteDashboardScenario parent} scenario
 * until the site dashboard has been reached.
 * <p/>
 * The following page is executed.  <b>*</b> indicates a possible start location.
 * <ul>
 *   <li><b>*  1. Site dashboard:</b> Selects the doclib</li>
 *   <li><b>   2. Site doclib:</b></li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ShareBrowseToSiteDocLibScenario extends ShareBrowseToSiteDashboardScenario
{
    public static final String EVENT_NAME_NAVIGATE_TO_DOCLIB = "share.nav.documentLibrary";

    private String eventNameNavigateToDocLib = EVENT_NAME_NAVIGATE_TO_DOCLIB;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     */
    public ShareBrowseToSiteDocLibScenario(ShareScenarioRegistry registry, double weight)
    {
        super(registry, weight);
    }

    /**
     * Override the {@link #EVENT_NAME_NAVIGATE_TO_CREATE_SITE default} name for events
     * to navigate to the create site page
     */
    public void setEventNameNavigateToDocLib(String eventNameNavigateToDocLib)
    {
        this.eventNameNavigateToDocLib = eventNameNavigateToDocLib;
    }

    /**
     * @see ShareCreateSiteScenario see class comments
     */
    @Override
    public List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime)
    {
        SharePage sharePage = eventData.getSharePage();
        if (sharePage instanceof DocumentLibraryPage)
        {
            // We have reached the end of the scenario
            return Collections.emptyList();
        }
        else if (sharePage instanceof SiteDashboardPage)
        {
            // We need to click the doclib link
            Event nextEvent = new Event(eventNameNavigateToDocLib, nextEventTime, eventData);
            return Collections.singletonList(nextEvent);
        }
        else
        {
            // Follow the parent class's actions
            return super.getNextEvents(event, eventData, soakData, nextEventTime);
        }
    }
}
