/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.Collections;
import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.po.share.DashBoardPage;
import org.alfresco.po.share.SharePage;

/**
 * Browses to the user dashboard.
 * <p/>
 * The following page is executed.  <b>*</b> indicates a possible start location.
 * <ul>
 *   <li><b>*  1. Any page after login:</b></li>
 *   <li><b>   2. User dashboard:</b></li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class ShareBrowseToUserDashboardScenario extends AbstractShareScenario
{
    public static final String EVENT_NAME_NAVIGATE_TO_DASHBOARD = "share.nav.dashboard";

    private String eventNameNavigateToDashboard = EVENT_NAME_NAVIGATE_TO_DASHBOARD;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     */
    public ShareBrowseToUserDashboardScenario(ShareScenarioRegistry registry, double weight)
    {
        super(registry, weight);
    }

    /**
     * Override the {@link #EVENT_NAME_NAVIGATE_TO_DASHBOARD default} name for events
     * to navigate to the user dashboard
     */
    public void setEventNameNavigateToDashboard(String eventNameNavigateToDashboard)
    {
        this.eventNameNavigateToDashboard = eventNameNavigateToDashboard;
    }

    /**
     * If the browser is <b>not</b> on the user dashboard then an event is fired to navigate to
     * the user dashboard.  If the user dashboard is the currrent page then nothing is done.
     */
    @Override
    public List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime)
    {
        SharePage sharePage = eventData.getSharePage();
        if (sharePage instanceof DashBoardPage)
        {
            // We're alread there.
            return Collections.emptyList();
        }
        else
        {
            Event nextEvent = new Event(eventNameNavigateToDashboard, nextEventTime, eventData);
            return Collections.singletonList(nextEvent);
        }
    }
}
