/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.Collections;
import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.bm.process.share.entity.SharePagingEventData;
import org.alfresco.po.share.SharePage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Pages through document library listings
 * <p/>
 * The following page is executed.  <b>*</b> indicates a possible start location.
 * <ul>
 *   <li><b>*  1. Site doclib (with pages):</b> Pages forward or backwards.  Can return to this page.</li>
 *   <li><b>   2.1. Site doclib:</b> END</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.0
 */
public class SharePageDocLibScenario extends AbstractShareScenario
{
    public static final String EVENT_NAME_DOCLIB_PAGE = "share.doclib.page";

    private String eventNameDocLibPage = EVENT_NAME_DOCLIB_PAGE;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     */
    public SharePageDocLibScenario(ShareScenarioRegistry registry, double weight)
    {
        super(registry, weight);
    }

    /**
     * Override the {@link #EVENT_NAME_DOCLIB_PAGE default} name for events
     * to page forward or backwards
     */
    public void setEventNameDocLibPage(String eventNameDocLibPage)
    {
        this.eventNameDocLibPage = eventNameDocLibPage;
    }

    /**
     * @see ShareCreateSiteScenario see class comments
     */
    @Override
    public List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime)
    {
        SharePage sharePage = eventData.getSharePage();
        if (eventData instanceof SharePagingEventData)
        {
            // We've just done some paging
            return Collections.emptyList();
        }
        else if (sharePage instanceof DocumentLibraryPage)
        {
            DocumentLibraryPage documentLibraryPage = (DocumentLibraryPage) sharePage;
            SharePagingEventData pagingData = null;
            // Are there any pages ahead?
            if (documentLibraryPage.hasNextPage())
            {
                pagingData = new SharePagingEventData(eventData, true, -1);
            }
            else if (documentLibraryPage.hasPreviousPage())
            {
                pagingData = new SharePagingEventData(eventData, false, -1);
            }
            else
            {
                // No pages
                return Collections.emptyList();
            }
            Event nextEvent = new Event(eventNameDocLibPage, nextEventTime, pagingData);
            // Done
            return Collections.singletonList(nextEvent);
        }
        else
        {
            // Not a page of interest
            return Collections.emptyList();
        }
    }
}
