/*
 * Copyright (C) 2005-2013 Alfresco Software Limited.
 *
 * This file is part of Alfresco
 *
 * Alfresco is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Alfresco is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Alfresco. If not, see <http://www.gnu.org/licenses/>.
 */
package org.alfresco.bm.process.share.soak;

import java.util.Collections;
import java.util.List;

import org.alfresco.bm.event.Event;
import org.alfresco.bm.process.share.entity.ShareEventData;
import org.alfresco.po.share.RepositoryPage;
import org.alfresco.po.share.SharePage;
import org.alfresco.po.share.site.document.DocumentLibraryPage;

/**
 * Scenarios around repository browser.
 * <p/>
 * The following page is executed.  <b>*</b> indicates a possible start location.
 * <ul>
 *   <li><b>*  1. Any page after login:</b> Select <i>Repository</i> link.</li>
 *   <li><b>*  2. {@link RepositoryPage}:</b> Treated as {@link DocumentLibraryPage}</li>
 * </ul>
 * 
 * @author Derek Hulley
 * @since 1.1
 */
public class ShareRepoBrowserScenario extends AbstractShareScenario
{
    public static final String EVENT_NAME_NAVIGATE_TO_REPO = "share.nav.repo";

    private String eventNameNavigateToRepo = EVENT_NAME_NAVIGATE_TO_REPO;
    
    /**
     * @param registry              registry with which this instance will be registered
     * @param weight                the weight relative to other scenarios registered in the registry
     * @param userDataService       service giving access to random usernames
     */
    public ShareRepoBrowserScenario(ShareScenarioRegistry registry, double weight)
    {
        super(registry, weight);
    }

    /**
     * Override the {@link #EVENT_NAME_NAVIGATE_TO_REPO default} name for events
     * to navigate to the <i>Repository</i> screen.
     */
    public void setEventNameNavigateToRepo(String eventNameNavigateToRepo)
    {
        this.eventNameNavigateToRepo = eventNameNavigateToRepo;
    }

    /**
     * If the browser is not on the {@link RepositoryPage} the link is clicked.<br/>
     */
    @Override
    public List<Event> getNextEvents(
            Event event,
            ShareEventData eventData,
            ShareSoakData soakData,
            long nextEventTime)
    {
        SharePage sharePage = eventData.getSharePage();
        if (sharePage instanceof RepositoryPage)
        {
            // TODO: Redirect to doclib scenarios
            return Collections.emptyList();
        }
        else
        {
            Event nextEvent = new Event(eventNameNavigateToRepo, nextEventTime, eventData);
            return Collections.singletonList(nextEvent);
        }
    }
}
